@@ -37,7 +37,7 @@ exports.configure = function(){
         inquirer.prompt(questions).then(function(res){
           nconf.set("threescale:id", res.threescale_id);
           nconf.set("threescale:access_token", res.threescale_access_token);
-          nconf.set("threescale:wildcard", res.threescale_wildcard);
+          nconf.set("threescale:wildcard", res.threescale_wildcard || "3scale.net");
           nconf.save(function (err) {
             fs.readFile(osHomedir()+"/.3scale/credentials.json", function (err, data) {
               // console.dir(JSON.parse(data.toString()))
